==> aliyun-python-sdk-alinlp-1.0.15.tar.gz: aliyun-python-sdk-alinlp-1.0.15/aliyunsdkalinlp/request/v20200629/GetWsCustomizedChO2ORequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkalinlp.endpoint import endpoint_data

class GetWsCustomizedChO2ORequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'alinlp', '2020-06-29', 'GetWsCustomizedChO2O','alinlp')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ServiceCode(self):
		return self.get_body_params().get('ServiceCode')

	def set_ServiceCode(self,ServiceCode):
		self.add_body_params('ServiceCode', ServiceCode)

	def get_TokenizerId(self):
		return self.get_body_params().get('TokenizerId')

	def set_TokenizerId(self,TokenizerId):
		self.add_body_params('TokenizerId', TokenizerId)

	def get_Text(self):
		return self.get_body_params().get('Text')

	def set_Text(self,Text):
		self.add_body_params('Text', Text)

	def get_OutType(self):
		return self.get_body_params().get('OutType')

	def set_OutType(self,OutType):
		self.add_body_params('OutType', OutType)

==> aliyun-python-sdk-alinlp-1.0.19.tar.gz: aliyun-python-sdk-alinlp-1.0.19/aliyunsdkalinlp/request/v20200629/GetWsCustomizedChO2ORequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkalinlp.endpoint import endpoint_data

class GetWsCustomizedChO2ORequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'alinlp', '2020-06-29', 'GetWsCustomizedChO2O','alinlp')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ServiceCode(self): # String
		return self.get_body_params().get('ServiceCode')

	def set_ServiceCode(self, ServiceCode):  # String
		self.add_body_params('ServiceCode', ServiceCode)
	def get_TokenizerId(self): # String
		return self.get_body_params().get('TokenizerId')

	def set_TokenizerId(self, TokenizerId):  # String
		self.add_body_params('TokenizerId', TokenizerId)
	def get_Text(self): # String
		return self.get_body_params().get('Text')

	def set_Text(self, Text):  # String
		self.add_body_params('Text', Text)
	def get_OutType(self): # String
		return self.get_body_params().get('OutType')

	def set_OutType(self, OutType):  # String
		self.add_body_params('OutType', OutType)
